# NextJS App

Generated by `pd init next`.

## Structure

- `/app` contains the main application code.
- `/public` serves static files such as images.

```bash
|-- app/
    |-- ui/ # Frontend code
        |-- fonts.ts # Font imports
        |-- global.css # Global styles
    |-- layout.tsx # Next.js layout
    |-- page.tsx # Next.js page
|-- static/ # Static files
    |-- favicon.ico
    |-- logo192.png
    |-- logo512.png
    |-- manifest.json
    |-- robots.txt
|-- .eslintrc.json # ESLint configuration
|-- .gitignore
|-- next.config.mjs # Next.js configuration
|-- next-env.d.ts # Next.js Environment
|-- package.json # Node.js dependencies
|-- postcss.config.js # PostCSS configuration
|-- README.md # This file
|-- tailwind.config.js # Tailwind CSS configuration
|-- tsconfig.json # TypeScript configuration
```

## Install

In the root directory of the project, run:

```bash
npm install
```

## Run

In the root directory of the project, run:

```bash
npm run dev
```

Open [http://localhost:3000](http://localhost:3000) with your browser to see the result.

## Learn More

To learn Next.js, check out the [Next.js documentation](https://nextjs.org/docs).